@@ -19,8 +19,8 @@
  *
  ****************************************************************************/
 
-#ifndef _UTOUCH_FRAME_MTDEV_H
-#define _UTOUCH_FRAME_MTDEV_H
+#ifndef UTOUCH_FRAME_MTDEV_H
+#define UTOUCH_FRAME_MTDEV_H
 
 #ifdef __cplusplus
 extern "C" {
