@@ -19,8 +19,8 @@
  *
  ****************************************************************************/
 
-#ifndef _FRAME_IMPL_H
-#define _FRAME_IMPL_H
+#ifndef FRAME_IMPL_H
+#define FRAME_IMPL_H
 
 #include <utouch/frame.h>
 
@@ -35,6 +35,7 @@ struct utouch_frame_engine {
 	struct utouch_frame *next;
 	int *evmap;
 	float map[9];
+	unsigned int semi_mt_num_active;
 };
 
 #endif
